import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_certificatemanager._jsii
import aws_cdk.aws_cognito._jsii
import aws_cdk.aws_dynamodb._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_elasticsearch._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_opensearchservice._jsii
import aws_cdk.aws_rds._jsii
import aws_cdk.aws_s3_assets._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-appsync", "1.159.0", __name__[0:-6], "aws-appsync@1.159.0.jsii.tgz"
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
